@@ -157,10 +157,10 @@ static char * nocollate_xpm[] = {
 static GtkVBoxClass *parent_class;
 static guint gpc_signals[LAST_SIGNAL] = {0};
 
-guint
+GtkType
 gnome_print_copies_selection_get_type (void)
 {
-	static guint copies_type = 0;
+	static GtkType copies_type = 0;
 	if (!copies_type) {
 		GtkTypeInfo copies_info = {
 			"GnomePrintCopiesSelection",
