@@ -78,10 +78,10 @@ typedef struct _GnomePrintDialoguePrivate {
 	GtkWidget *range_end;
 } Private;
 
-guint
+GtkType
 gnome_print_dialog_get_type (void)
 {
-	static guint select_paper_type = 0;
+	static GtkType select_paper_type = 0;
   
 	if (!select_paper_type) {
 		GtkTypeInfo select_paper_info = {
