@@ -783,10 +783,10 @@ static void gnome_print_master_preview_init (GnomePrintMasterPreview *pmp);
 
 static GtkWindowClass *parent_class;
 
-guint
+GtkType
 gnome_print_master_preview_get_type (void)
 {
-	static guint print_master_preview_type = 0;
+	static GtkType print_master_preview_type = 0;
 	
 	if (!print_master_preview_type) {
 		GtkTypeInfo print_master_preview_info = {
