@@ -18,9 +18,10 @@
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include "media-orientation.h"
 
+#define PADDING 2
+
 static void gpa_mow_changed (GtkWidget *w, GPAMediaOrientationWidget *mow);
 static void gpa_mow_config_changed (GPANode *node, GPAMediaOrientationWidget *mow);
 
@@ -51,21 +52,21 @@ gpa_media_orientation_widget_construct (GPAMediaOrientationWidget *mow, GPANode
 
 	gpa_widget_construct (GPA_WIDGET (mow), node);
 
-	vb = gtk_vbox_new (TRUE, GNOME_PAD_SMALL);
+	vb = gtk_vbox_new (TRUE, PADDING);
 	gtk_container_add (GTK_CONTAINER (mow), vb);
 
 	b = gtk_radio_button_new_with_label (NULL, _("Portrait"));
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (b));
-	gtk_box_pack_start (GTK_BOX (vb), b, TRUE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (vb), b, TRUE, FALSE, PADDING);
 	gtk_object_set_data (GTK_OBJECT (mow), "portrait", b);
 	gtk_signal_connect (GTK_OBJECT (b), "toggled", GTK_SIGNAL_FUNC (gpa_mow_changed), mow);
 	b = gtk_radio_button_new_with_label (group, _("Landscape"));
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (b));
-	gtk_box_pack_start (GTK_BOX (vb), b, TRUE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (vb), b, TRUE, FALSE, PADDING);
 	gtk_object_set_data (GTK_OBJECT (mow), "landscape", b);
 	gtk_signal_connect (GTK_OBJECT (b), "toggled", GTK_SIGNAL_FUNC (gpa_mow_changed), mow);
 	b = gtk_check_button_new_with_label (_("Rotate 180"));
-	gtk_box_pack_start (GTK_BOX (vb), b, TRUE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (vb), b, TRUE, FALSE, PADDING);
 	gtk_object_set_data (GTK_OBJECT (mow), "rotate", b);
 	gtk_signal_connect (GTK_OBJECT (b), "toggled", GTK_SIGNAL_FUNC (gpa_mow_changed), mow);
 	gtk_widget_show_all (vb);
