@@ -13,9 +13,9 @@
  *
  */
 
-#include <libgnome/gnome-defs.h>
+#include <glib/gmacros.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #include "gpa-widget.h"
 
@@ -31,6 +31,6 @@ typedef struct _GPAWidgetClass GPAMediaOrinetationWidgetClass;
 GtkWidget *gpa_media_orientation_widget_new (GPANode *node);
 void gpa_media_orientation_widget_construct (GPAMediaOrientationWidget *widget, GPANode *node);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
